This package contains interviews that help Litigants in Person 
to complete court forms for HM Courts and Tribunals Service when
**support from a lawyer is not available**.

The package currently contains interviews to help a LIP:

- complete form N244 - an application notice 
    (https://www.gov.uk/government/publications/form-n244-application-notice)
- produce a witness statement in the correct prescribed format